CLKComplicationDataSource

Trait CLKComplicationDataSource 

pub unsafe trait CLKComplicationDataSource: NSObjectProtocol + MainThreadOnly {
Show 17 methods // Provided methods unsafe fn getTimelineEndDateForComplication_withHandler( &self, complication: &CLKComplication, handler: &DynBlock<dyn Fn(*mut NSDate)>, ) where Self: Sized + Message { ... } unsafe fn getPrivacyBehaviorForComplication_withHandler( &self, complication: &CLKComplication, handler: &DynBlock<dyn Fn(CLKComplicationPrivacyBehavior)>, ) where Self: Sized + Message { ... } unsafe fn getTimelineAnimationBehaviorForComplication_withHandler( &self, complication: &CLKComplication, handler: &DynBlock<dyn Fn(CLKComplicationTimelineAnimationBehavior)>, ) where Self: Sized + Message { ... } unsafe fn getAlwaysOnTemplateForComplication_withHandler( &self, complication: &CLKComplication, handler: &DynBlock<dyn Fn(*mut CLKComplicationTemplate)>, ) where Self: Sized + Message { ... } unsafe fn getCurrentTimelineEntryForComplication_withHandler( &self, complication: &CLKComplication, handler: &DynBlock<dyn Fn(*mut CLKComplicationTimelineEntry)>, ) where Self: Sized + Message { ... } unsafe fn getTimelineEntriesForComplication_afterDate_limit_withHandler( &self, complication: &CLKComplication, date: &NSDate, limit: NSUInteger, handler: &DynBlock<dyn Fn(*mut NSArray<CLKComplicationTimelineEntry>)>, ) where Self: Sized + Message { ... } unsafe fn getLocalizableSampleTemplateForComplication_withHandler( &self, complication: &CLKComplication, handler: &DynBlock<dyn Fn(*mut CLKComplicationTemplate)>, ) where Self: Sized + Message { ... } unsafe fn getComplicationDescriptorsWithHandler( &self, handler: &DynBlock<dyn Fn(NonNull<NSArray<CLKComplicationDescriptor>>)>, ) where Self: Sized + Message { ... } unsafe fn handleSharedComplicationDescriptors( &self, complication_descriptors: &NSArray<CLKComplicationDescriptor>, ) where Self: Sized + Message { ... } unsafe fn widgetMigrator( &self, ) -> Retained<ProtocolObject<dyn CLKComplicationWidgetMigrator>> where Self: Sized + Message { ... } unsafe fn getPlaceholderTemplateForComplication_withHandler( &self, complication: &CLKComplication, handler: &DynBlock<dyn Fn(*mut CLKComplicationTemplate)>, ) where Self: Sized + Message { ... } unsafe fn getSupportedTimeTravelDirectionsForComplication_withHandler( &self, complication: &CLKComplication, handler: &DynBlock<dyn Fn(CLKComplicationTimeTravelDirections)>, ) where Self: Sized + Message { ... } unsafe fn getTimelineStartDateForComplication_withHandler( &self, complication: &CLKComplication, handler: &DynBlock<dyn Fn(*mut NSDate)>, ) where Self: Sized + Message { ... } unsafe fn getTimelineEntriesForComplication_beforeDate_limit_withHandler( &self, complication: &CLKComplication, date: &NSDate, limit: NSUInteger, handler: &DynBlock<dyn Fn(*mut NSArray<CLKComplicationTimelineEntry>)>, ) where Self: Sized + Message { ... } unsafe fn getNextRequestedUpdateDateWithHandler( &self, handler: &DynBlock<dyn Fn(*mut NSDate)>, ) where Self: Sized + Message { ... } unsafe fn requestedUpdateDidBegin(&self) where Self: Sized + Message { ... } unsafe fn requestedUpdateBudgetExhausted(&self) where Self: Sized + Message { ... }
}
Available on crate feature CLKComplicationDataSource only.
Provided Methods

unsafe fn getTimelineEndDateForComplication_withHandler( &self, complication: &CLKComplication, handler: &DynBlock<dyn Fn(*mut NSDate)>, )
where Self: Sized + Message,

👎Deprecated:

On watchOS 9.0 or later, use WidgetKit instead

Available on crate features block2 and CLKComplication only.
unsafe fn getPrivacyBehaviorForComplication_withHandler( &self, complication: &CLKComplication, handler: &DynBlock<dyn Fn(CLKComplicationPrivacyBehavior)>, )
where Self: Sized + Message,

👎Deprecated:

On watchOS 9.0 or later, use WidgetKit instead

Available on crate features block2 and CLKComplication and CLKDefines only.
unsafe fn getTimelineAnimationBehaviorForComplication_withHandler( &self, complication: &CLKComplication, handler: &DynBlock<dyn Fn(CLKComplicationTimelineAnimationBehavior)>, )
where Self: Sized + Message,

👎Deprecated:

On watchOS 9.0 or later, use WidgetKit instead

Available on crate features block2 and CLKComplication and CLKDefines only.
unsafe fn getAlwaysOnTemplateForComplication_withHandler( &self, complication: &CLKComplication, handler: &DynBlock<dyn Fn(*mut CLKComplicationTemplate)>, )
where Self: Sized + Message,

👎Deprecated:

On watchOS 9.0 or later, use WidgetKit instead

Available on crate features block2 and CLKComplication and CLKComplicationTemplate only.
unsafe fn getCurrentTimelineEntryForComplication_withHandler( &self, complication: &CLKComplication, handler: &DynBlock<dyn Fn(*mut CLKComplicationTimelineEntry)>, )
where Self: Sized + Message,

👎Deprecated:

On watchOS 9.0 or later, use WidgetKit instead

Available on crate features block2 and CLKComplication and CLKComplicationTimelineEntry only.
unsafe fn getTimelineEntriesForComplication_afterDate_limit_withHandler( &self, complication: &CLKComplication, date: &NSDate, limit: NSUInteger, handler: &DynBlock<dyn Fn(*mut NSArray<CLKComplicationTimelineEntry>)>, )
where Self: Sized + Message,

👎Deprecated:

On watchOS 9.0 or later, use WidgetKit instead

Available on crate features block2 and CLKComplication and CLKComplicationTimelineEntry only.
unsafe fn getLocalizableSampleTemplateForComplication_withHandler( &self, complication: &CLKComplication, handler: &DynBlock<dyn Fn(*mut CLKComplicationTemplate)>, )
where Self: Sized + Message,

👎Deprecated:

On watchOS 9.0 or later, use WidgetKit instead

Available on crate features block2 and CLKComplication and CLKComplicationTemplate only.
unsafe fn getComplicationDescriptorsWithHandler( &self, handler: &DynBlock<dyn Fn(NonNull<NSArray<CLKComplicationDescriptor>>)>, )
where Self: Sized + Message,

👎Deprecated:

On watchOS 9.0 or later, use WidgetKit instead

Available on crate features block2 and CLKComplicationDescriptor only.
unsafe fn handleSharedComplicationDescriptors( &self, complication_descriptors: &NSArray<CLKComplicationDescriptor>, )
where Self: Sized + Message,

👎Deprecated:

On watchOS 9.0 or later, use WidgetKit instead

Available on crate feature CLKComplicationDescriptor only.
unsafe fn widgetMigrator( &self, ) -> Retained<ProtocolObject<dyn CLKComplicationWidgetMigrator>>
where Self: Sized + Message,

Available on crate feature CLKComplicationWidgetMigrator only.
unsafe fn getPlaceholderTemplateForComplication_withHandler( &self, complication: &CLKComplication, handler: &DynBlock<dyn Fn(*mut CLKComplicationTemplate)>, )
where Self: Sized + Message,

👎Deprecated
Available on crate features block2 and CLKComplication and CLKComplicationTemplate only.
unsafe fn getSupportedTimeTravelDirectionsForComplication_withHandler( &self, complication: &CLKComplication, handler: &DynBlock<dyn Fn(CLKComplicationTimeTravelDirections)>, )
where Self: Sized + Message,

👎Deprecated:

Time Travel is no longer supported. Use CLKComplicationDataSource’s getTimelineEndDateForComplication:withHandler: to specify forward timeline support.

Available on crate features block2 and CLKComplication and CLKDefines only.
unsafe fn getTimelineStartDateForComplication_withHandler( &self, complication: &CLKComplication, handler: &DynBlock<dyn Fn(*mut NSDate)>, )
where Self: Sized + Message,

👎Deprecated:

Time Travel and backwards extension of timelines are no longer supported.

Available on crate features block2 and CLKComplication only.
unsafe fn getTimelineEntriesForComplication_beforeDate_limit_withHandler( &self, complication: &CLKComplication, date: &NSDate, limit: NSUInteger, handler: &DynBlock<dyn Fn(*mut NSArray<CLKComplicationTimelineEntry>)>, )
where Self: Sized + Message,

👎Deprecated:

Time Travel and backwards extension of timelines are no longer supported.

Available on crate features block2 and CLKComplication and CLKComplicationTimelineEntry only.
unsafe fn getNextRequestedUpdateDateWithHandler( &self, handler: &DynBlock<dyn Fn(*mut NSDate)>, )
where Self: Sized + Message,

👎Deprecated:

Use WKRefreshBackgroundTask instead

Available on crate feature block2 only.
unsafe fn requestedUpdateDidBegin(&self)
where Self: Sized + Message,

👎Deprecated:

Use WKRefreshBackgroundTask instead

unsafe fn requestedUpdateBudgetExhausted(&self)
where Self: Sized + Message,

👎Deprecated:

Use WKRefreshBackgroundTask instead